@@ -7,7 +7,7 @@ test_that("map_gist works as expected", {
 
   spp <- c('Danaus plexippus','Accipiter striatus','Pinus contorta')
   dat <- occ(spp, from = 'gbif', limit = 30, has_coords = TRUE)
-  dat <- fixnames(dat, "query")
+  dat <- suppressWarnings(fixnames(dat, "query"))
 
   # Define colors
   g <- suppressMessages(map_gist(dat, color = c('#976AAE','#6B944D','#BD5945'), browse = FALSE))
